@@ -36,8 +36,8 @@
 #include <Akonadi/Calendar/IncidenceChanger>
 #include <CalendarSupport/Utils>
 
-#include <KCalCore/Incidence>
-#include <KCalCore/Todo>
+#include <KCalendarCore/Incidence>
+#include <KCalendarCore/Todo>
 
 #include <KCalUtils/RecurrenceActions>
 
@@ -68,9 +68,6 @@ public:
     Private(EventView *eventView, Agenda *agenda)
         : mEventView(eventView)
         , mAgenda(agenda)
-        , mTimer(nullptr)
-        , mTimeBox(nullptr)
-        , mOldTodayCol(-1)
     {
     }
 
@@ -82,7 +79,7 @@ public:
     QTimer *mTimer = nullptr;
     QLabel *mTimeBox = nullptr;  // Label showing the current time
     QDateTime mOldDateTime;
-    int mOldTodayCol;
+    int mOldTodayCol = -1;
 };
 
 int MarcusBains::Private::todayColumn() const
@@ -90,8 +87,8 @@ int MarcusBains::Private::todayColumn() const
     const QDate currentDate = QDate::currentDate();
 
     int col = 0;
-    const KCalCore::DateList dateList = mAgenda->dateList();
-    foreach (const QDate &date, dateList) {
+    const KCalendarCore::DateList dateList = mAgenda->dateList();
+    for (const QDate &date : dateList) {
         if (date == currentDate) {
             return QApplication::isRightToLeft() ? mAgenda->columns() - 1 - col : col;
         }
@@ -208,8 +205,7 @@ void MarcusBains::updateLocationRecalc(bool recalculate)
 class Q_DECL_HIDDEN Agenda::Private
 {
 public:
-    Private(AgendaView *agendaView, QScrollArea *scrollArea, int columns, int rows, int rowSize,
-            bool isInteractive)
+    Private(AgendaView *agendaView, QScrollArea *scrollArea, int columns, int rows, int rowSize, bool isInteractive)
         : mAgendaView(agendaView)
         , mScrollArea(scrollArea)
         , mAllDayMode(false)
@@ -255,7 +251,8 @@ public:
         return mItemsQueuedForDeletion.contains(uid) && !mAgendaItemsById.contains(uid);
     }
 
-    QMultiHash<QString, AgendaItem::QPtr> mAgendaItemsById; // It's a QMultiHash because recurring incidences might have many agenda items
+    QMultiHash<QString, AgendaItem::QPtr> mAgendaItemsById; // A QMultiHash because recurring incs
+                                                            // might have many agenda items
     QSet<QString> mItemsQueuedForDeletion;
 
     AgendaView *mAgendaView = nullptr;
@@ -304,7 +301,7 @@ public:
     QPoint mSelectionEndCell;
 
     // List of dates to be displayed
-    KCalCore::DateList mSelectedDates;
+    KCalendarCore::DateList mSelectedDates;
 
     // The AgendaItem, which has been right-clicked last
     QPointer<AgendaItem> mClickedItem;
@@ -342,8 +339,7 @@ public:
 /*
   Create an agenda widget with rows rows and columns columns.
 */
-Agenda::Agenda(AgendaView *agendaView, QScrollArea *scrollArea, int columns, int rows, int rowSize,
-               bool isInteractive)
+Agenda::Agenda(AgendaView *agendaView, QScrollArea *scrollArea, int columns, int rows, int rowSize, bool isInteractive)
     : QWidget(scrollArea)
     , d(new Private(agendaView, scrollArea, columns, rows, rowSize, isInteractive))
 {
@@ -372,9 +368,9 @@ Agenda::~Agenda()
     delete d;
 }
 
-KCalCore::Incidence::Ptr Agenda::selectedIncidence() const
+KCalendarCore::Incidence::Ptr Agenda::selectedIncidence() const
 {
-    return d->mSelectedItem ? d->mSelectedItem->incidence() : KCalCore::Incidence::Ptr();
+    return d->mSelectedItem ? d->mSelectedItem->incidence() : KCalendarCore::Incidence::Ptr();
 }
 
 QDate Agenda::selectedIncidenceDate() const
@@ -543,7 +539,7 @@ bool Agenda::eventFilter(QObject *object, QEvent *event)
     case QEvent::KeyRelease:
         return eventFilter_key(object, static_cast<QKeyEvent *>(event));
 
-    case (QEvent::Leave):
+    case QEvent::Leave:
 #ifndef QT_NO_CURSOR
         if (!d->mActionItem) {
             setCursor(Qt::ArrowCursor);
@@ -603,7 +599,7 @@ bool Agenda::eventFilter_drag(QObject *obj, QDropEvent *de)
         }
 
         const QList<QUrl> incidenceUrls = CalendarSupport::incidenceItemUrls(md);
-        const KCalCore::Incidence::List incidences = CalendarSupport::incidences(md);
+        const KCalendarCore::Incidence::List incidences = CalendarSupport::incidences(md);
 
         Q_ASSERT(!incidenceUrls.isEmpty() || !incidences.isEmpty());
 
@@ -638,25 +634,30 @@ bool Agenda::eventFilter_wheel(QObject *object, QWheelEvent *e)
 {
     QPoint viewportPos;
     bool accepted = false;
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
+    const QPoint pos = e->pos();
+#else
+    const QPoint pos = e->position().toPoint();
+#endif
     if ((e->modifiers() & Qt::ShiftModifier) == Qt::ShiftModifier) {
         if (object != this) {
-            viewportPos = ((QWidget *)object)->mapToParent(e->pos());
+            viewportPos = ((QWidget *)object)->mapToParent(pos);
         } else {
-            viewportPos = e->pos();
+            viewportPos = pos;
         }
-        //qCDebug(CALENDARVIEW_LOG) << type:" << e->type() << "delta:" << e->delta();
-        Q_EMIT zoomView(-e->delta(),
+        //qCDebug(CALENDARVIEW_LOG) << type:" << e->type() << "angleDelta:" << e->angleDelta();
+        Q_EMIT zoomView(-e->angleDelta().y(),
                         contentsToGrid(viewportPos), Qt::Horizontal);
         accepted = true;
     }
 
     if ((e->modifiers() & Qt::ControlModifier) == Qt::ControlModifier) {
         if (object != this) {
-            viewportPos = ((QWidget *)object)->mapToParent(e->pos());
+            viewportPos = ((QWidget *)object)->mapToParent(pos);
         } else {
-            viewportPos = e->pos();
+            viewportPos = pos;
         }
-        Q_EMIT zoomView(-e->delta(), contentsToGrid(viewportPos), Qt::Vertical);
+        Q_EMIT zoomView(-e->angleDelta().y(), contentsToGrid(viewportPos), Qt::Vertical);
         Q_EMIT mousePosSignal(gridToContents(contentsToGrid(viewportPos)));
         accepted = true;
     }
@@ -695,7 +696,7 @@ bool Agenda::eventFilter_mouse(QObject *object, QMouseEvent *me)
             } else {
                 AgendaItem::QPtr item = qobject_cast<AgendaItem *>(object);
                 if (item) {
-                    KCalCore::Incidence::Ptr incidence = item->incidence();
+                    KCalendarCore::Incidence::Ptr incidence = item->incidence();
                     if (incidence->isReadOnly()) {
                         d->mActionItem = nullptr;
                     } else {
@@ -721,7 +722,7 @@ bool Agenda::eventFilter_mouse(QObject *object, QMouseEvent *me)
                     Q_EMIT newTimeSpanSignal(d->mSelectionStartCell, d->mSelectionEndCell);
 //          updateContents();
                 }
-                showNewEventPopupSignal();
+                Q_EMIT showNewEventPopupSignal();
             } else {
                 selectItem(nullptr);
                 d->mActionItem = nullptr;
@@ -756,8 +757,8 @@ bool Agenda::eventFilter_mouse(QObject *object, QMouseEvent *me)
         QPoint indicatorPos = gridToContents(contentsToGrid(viewportPos));
         if (object != this) {
             AgendaItem::QPtr moveItem = qobject_cast<AgendaItem *>(object);
-            KCalCore::Incidence::Ptr incidence
-                = moveItem ? moveItem->incidence() : KCalCore::Incidence::Ptr();
+            KCalendarCore::Incidence::Ptr incidence
+                = moveItem ? moveItem->incidence() : KCalendarCore::Incidence::Ptr();
             if (incidence && !incidence->isReadOnly()) {
                 if (!d->mActionItem) {
                     setNoActionCursor(moveItem, viewportPos);
@@ -821,7 +822,8 @@ bool Agenda::ptInSelection(const QPoint &gpos) const
 {
     if (!d->mHasSelection) {
         return false;
-    } else if (gpos.x() < d->mSelectionStartCell.x() || gpos.x() > d->mSelectionEndCell.x()) {
+    } else if (gpos.x() < d->mSelectionStartCell.x()
+               || gpos.x() > d->mSelectionEndCell.x()) {
         return false;
     } else if ((gpos.x() == d->mSelectionStartCell.x())
                && (gpos.y() < d->mSelectionStartCell.y())) {
@@ -860,8 +862,7 @@ void Agenda::performSelectAction(const QPoint &pos)
     // Scroll if cursor was moved to upper or lower end of agenda.
     if (pos.y() - contentsY() < d->mScrollBorderWidth && contentsY() > 0) {
         d->mScrollUpTimer.start(d->mScrollDelay);
-    } else if (contentsY() + d->mScrollArea->viewport()->height()
-               -d->mScrollBorderWidth < pos.y()) {
+    } else if (contentsY() + d->mScrollArea->viewport()->height() - d->mScrollBorderWidth < pos.y()) {
         d->mScrollDownTimer.start(d->mScrollDelay);
     } else {
         d->mScrollUpTimer.stop();
@@ -894,15 +895,13 @@ void Agenda::endSelectAction(const QPoint &currentPos)
     Q_EMIT newTimeSpanSignal(d->mSelectionStartCell, d->mSelectionEndCell);
 
     if (d->preferences()->selectionStartsEditor()) {
-        if ((d->mSelectionStartPoint - currentPos).manhattanLength()
-            > QApplication::startDragDistance()) {
+        if ((d->mSelectionStartPoint - currentPos).manhattanLength() > QApplication::startDragDistance()) {
             Q_EMIT newEventSignal();
         }
     }
 }
 
-Agenda::MouseActionType Agenda::isInResizeArea(bool horizontal, const QPoint &pos,
-                                               const AgendaItem::QPtr &item)
+Agenda::MouseActionType Agenda::isInResizeArea(bool horizontal, const QPoint &pos, const AgendaItem::QPtr &item)
 {
     if (!item) {
         return NOP;
@@ -939,10 +938,12 @@ Agenda::MouseActionType Agenda::isInResizeArea(bool horizontal, const QPoint &po
     } else {
         int gridDistanceY = int(pos.y() - contpos.y());
         if (gridDistanceY < d->mResizeBorderWidth
-            && item->cellYTop() == gridpos.y() && !item->firstMultiItem()) {
+            && item->cellYTop() == gridpos.y()
+            && !item->firstMultiItem()) {
             return RESIZETOP;
         } else if ((d->mGridSpacingY - gridDistanceY) < d->mResizeBorderWidth
-                   && item->cellYBottom() == gridpos.y() && !item->lastMultiItem()) {
+                   && item->cellYBottom() == gridpos.y()
+                   && !item->lastMultiItem()) {
             return RESIZEBOTTOM;
         } else {
             return MOVE;
@@ -974,8 +975,10 @@ void Agenda::performItemAction(const QPoint &pos)
 
     // Cursor left active agenda area.
     // This starts a drag.
-    if (pos.y() < 0 || pos.y() >= contentsY() + d->mScrollArea->viewport()->height()
-        || pos.x() < 0 || pos.x() >= width()) {
+    if (pos.y() < 0
+        || pos.y() >= contentsY() + d->mScrollArea->viewport()->height()
+        || pos.x() < 0
+        || pos.x() >= width()) {
         if (d->mActionType == MOVE) {
             d->mScrollUpTimer.stop();
             d->mScrollDownTimer.stop();
@@ -1001,8 +1004,7 @@ void Agenda::performItemAction(const QPoint &pos)
     const int distanceToTop = pos.y() - contentsY();
     if (distanceToTop < d->mScrollBorderWidth && distanceToTop > -d->mScrollBorderWidth) {
         d->mScrollUpTimer.start(d->mScrollDelay);
-    } else if (contentsY() + d->mScrollArea->viewport()->height()
-               -d->mScrollBorderWidth < pos.y()) {
+    } else if (contentsY() + d->mScrollArea->viewport()->height() - d->mScrollBorderWidth < pos.y()) {
         d->mScrollDownTimer.start(d->mScrollDelay);
     } else {
         d->mScrollUpTimer.stop();
@@ -1189,11 +1191,12 @@ void Agenda::endItemAction()
 
     bool multiModify = false;
     // FIXME: do the cloning here...
-    KCalCore::Incidence::Ptr incidence = d->mActionItem->incidence();
+    KCalendarCore::Incidence::Ptr incidence = d->mActionItem->incidence();
     const auto recurrenceId = d->mActionItem->occurrenceDateTime();
 
-    d->mItemMoved = d->mItemMoved && !(d->mStartCell.x() == d->mEndCell.x()
-                                       && d->mStartCell.y() == d->mEndCell.y());
+    d->mItemMoved
+        = d->mItemMoved
+          && !(d->mStartCell.x() == d->mEndCell.x() && d->mStartCell.y() == d->mEndCell.y());
 
     bool addIncidence = false;
     if (d->mItemMoved) {
@@ -1201,8 +1204,8 @@ void Agenda::endItemAction()
 
         //get the main event and not the exception
         if (incidence->hasRecurrenceId() && !incidence->recurs()) {
-            KCalCore::Incidence::Ptr mainIncidence;
-            KCalCore::Calendar::Ptr cal = d->mCalendar->findCalendar(incidence)->getCalendar();
+            KCalendarCore::Incidence::Ptr mainIncidence;
+            KCalendarCore::Calendar::Ptr cal = d->mCalendar->findCalendar(incidence)->getCalendar();
             if (CalendarSupport::hasEvent(incidence)) {
                 mainIncidence = cal->event(incidence->uid());
             } else if (CalendarSupport::hasTodo(incidence)) {
@@ -1217,7 +1220,7 @@ void Agenda::endItemAction()
             const int res = d->mAgendaView->showMoveRecurDialog(incidence, recurrenceId.date());
             switch (res) {
             case KCalUtils::RecurrenceActions::AllOccurrences: // All occurrences
-                // Moving the whole sequene of events is handled by the itemModified below.
+                // Moving the whole sequence of events is handled by the itemModified below.
                 modify = true;
                 break;
             case KCalUtils::RecurrenceActions::SelectedOccurrence:
@@ -1227,7 +1230,7 @@ void Agenda::endItemAction()
                 modify = true;
                 multiModify = true;
                 d->mChanger->startAtomicOperation(i18n("Dissociate event from recurrence"));
-                KCalCore::Incidence::Ptr newInc(KCalCore::Calendar::createException(
+                KCalendarCore::Incidence::Ptr newInc(KCalendarCore::Calendar::createException(
                                                     incidence, recurrenceId, thisAndFuture));
                 if (newInc) {
                     newInc->removeCustomProperty("VOLATILE", "AKONADI-ID");
@@ -1356,8 +1359,8 @@ void Agenda::setActionCursor(int actionType, bool acting)
 
 void Agenda::setNoActionCursor(const AgendaItem::QPtr &moveItem, const QPoint &pos)
 {
-    const KCalCore::Incidence::Ptr item
-        = moveItem ? moveItem->incidence() : KCalCore::Incidence::Ptr();
+    const KCalendarCore::Incidence::Ptr item
+        = moveItem ? moveItem->incidence() : KCalendarCore::Incidence::Ptr();
 
     const bool noResize = CalendarSupport::hasTodo(item);
 
@@ -1457,7 +1460,7 @@ void Agenda::placeSubCells(const AgendaItem::QPtr &placeItem)
 #if 0
     qCDebug(CALENDARVIEW_LOG);
     if (placeItem) {
-        KCalCore::Incidence::Ptr event = placeItem->incidence();
+        KCalendarCore::Incidence::Ptr event = placeItem->incidence();
         if (!event) {
             qCDebug(CALENDARVIEW_LOG) << "  event is 0";
         } else {
@@ -1470,7 +1473,7 @@ void Agenda::placeSubCells(const AgendaItem::QPtr &placeItem)
 #endif
 
     QList<CalendarSupport::CellItem *> cells;
-    foreach (CalendarSupport::CellItem *item, d->mItems) {
+    for (CalendarSupport::CellItem *item : qAsConst(d->mItems)) {
         if (item) {
             cells.append(item);
         }
@@ -1527,9 +1530,12 @@ void Agenda::drawContents(QPainter *p, int cx, int cy, int cw, int ch)
     //    QPixmap bgImage(d->preferences()->agendaGridBackgroundImage());
     //    dbp.drawPixmap(0, 0, cw, ch, bgImage); FIXME
     //  }
-
-    dbp.fillRect(0, 0, cw, ch,
-                 d->preferences()->agendaGridBackgroundColor());
+    if (!d->preferences()->useSystemColor()) {
+        dbp.fillRect(0, 0, cw, ch,
+                    d->preferences()->agendaGridBackgroundColor());
+    } else {
+        dbp.fillRect(0, 0, cw, ch, palette().color(QPalette::Window));
+    }
 
     dbp.translate(-cx, -cy);
 
@@ -1543,7 +1549,12 @@ void Agenda::drawContents(QPainter *p, int cx, int cy, int cw, int ch)
 
     // Highlight working hours
     if (d->mWorkingHoursEnable && d->mHolidayMask) {
-        const QColor workColor = d->preferences()->workingHoursColor();
+        QColor workColor;
+        if (!d->preferences()->useSystemColor()) {
+            workColor = d->preferences()->workingHoursColor();
+        } else {
+            workColor = palette().color(QPalette::Base);
+        }
 
         QPoint pt1(cx, d->mWorkingHoursYTop);
         QPoint pt2(cx + cw, d->mWorkingHoursYBottom);
@@ -1595,7 +1606,19 @@ void Agenda::drawContents(QPainter *p, int cx, int cy, int cw, int ch)
             if (busyDayMask[i]) {
                 const QPoint pt1(cx + d->mGridSpacingX *i, 0);
                 // const QPoint pt2(cx + mGridSpacingX * (i+1), ch);
-                QColor busyColor = d->preferences()->viewBgBusyColor();
+                QColor busyColor;
+                if (!d->preferences()->useSystemColor()) {
+                    busyColor = d->preferences()->viewBgBusyColor();
+                } else {
+                    busyColor = palette().color(QPalette::Window);
+                    if ((busyColor.blue() + busyColor.red() + busyColor.green()) > (256 / 2 * 3)) {
+                        // dark
+                        busyColor = busyColor.lighter(140);
+                    } else {
+                        // light
+                        busyColor = busyColor.darker(140);
+                    }
+                }
                 busyColor.setAlpha(EventViews::BUSY_BACKGROUND_ALPHA);
                 dbp.fillRect(pt1.x(), pt1.y(), d->mGridSpacingX, cy + ch, busyColor);
             }
@@ -1605,31 +1628,51 @@ void Agenda::drawContents(QPainter *p, int cx, int cy, int cw, int ch)
     // draw selection
     if (d->mHasSelection && d->mAgendaView->dateRangeSelectionEnabled()) {
         QPoint pt, pt1;
+        QColor highlightColor;
+        if (!d->preferences()->useSystemColor()) {
+            highlightColor = d->preferences()->agendaGridHighlightColor();
+        } else {
+            highlightColor = palette().color(QPalette::Highlight);
+        }
 
         if (d->mSelectionEndCell.x() > d->mSelectionStartCell.x()) {   // multi day selection
             // draw start day
             pt = gridToContents(d->mSelectionStartCell);
             pt1 = gridToContents(QPoint(d->mSelectionStartCell.x() + 1, d->mRows + 1));
-            dbp.fillRect(QRect(pt, pt1), d->preferences()->agendaGridHighlightColor());
+            dbp.fillRect(QRect(pt, pt1), highlightColor);
             // draw all other days between the start day and the day of the selection end
             for (int c = d->mSelectionStartCell.x() + 1; c < d->mSelectionEndCell.x(); ++c) {
                 pt = gridToContents(QPoint(c, 0));
                 pt1 = gridToContents(QPoint(c + 1, d->mRows + 1));
-                dbp.fillRect(QRect(pt, pt1), d->preferences()->agendaGridHighlightColor());
+                dbp.fillRect(QRect(pt, pt1), highlightColor);
             }
             // draw end day
             pt = gridToContents(QPoint(d->mSelectionEndCell.x(), 0));
             pt1 = gridToContents(d->mSelectionEndCell + QPoint(1, 1));
-            dbp.fillRect(QRect(pt, pt1), d->preferences()->agendaGridHighlightColor());
+            dbp.fillRect(QRect(pt, pt1), highlightColor);
         } else { // single day selection
             pt = gridToContents(d->mSelectionStartCell);
             pt1 = gridToContents(d->mSelectionEndCell + QPoint(1, 1));
-            dbp.fillRect(QRect(pt, pt1), d->preferences()->agendaGridHighlightColor());
+            dbp.fillRect(QRect(pt, pt1), highlightColor);
         }
     }
 
-    QPen hourPen(d->preferences()->agendaGridBackgroundColor().darker(150));
-    QPen halfHourPen(d->preferences()->agendaGridBackgroundColor().darker(125));
+    // Compute the grid line color for both the hour and half-hour
+    // The grid colors are always computed as a function of the palette's windowText color.
+    QPen hourPen;
+    QPen halfHourPen;
+
+    const QColor windowTextColor = palette().color(QPalette::WindowText);
+    if (windowTextColor.red() + windowTextColor.green() + windowTextColor.blue() < (256 / 2 * 3)) {
+        // dark grey line
+        hourPen = windowTextColor.lighter(200);
+        halfHourPen = windowTextColor.lighter(500);
+    } else {
+        // light grey line
+        hourPen = windowTextColor.darker(150);
+        halfHourPen = windowTextColor.darker(200);
+    }
+
     dbp.setPen(hourPen);
 
     // Draw vertical lines of grid, start with the last line not yet visible
@@ -1660,7 +1703,8 @@ void Agenda::drawContents(QPainter *p, int cx, int cy, int cw, int ch)
 QPoint Agenda::contentsToGrid(const QPoint &pos) const
 {
     int gx = int(QApplication::isRightToLeft()
-                 ? d->mColumns - pos.x() / d->mGridSpacingX : pos.x() / d->mGridSpacingX);
+                 ? d->mColumns - pos.x() / d->mGridSpacingX
+                 : pos.x() / d->mGridSpacingX);
     int gy = int(pos.y() / d->mGridSpacingY);
     return QPoint(gx, gy);
 }
@@ -1671,7 +1715,8 @@ QPoint Agenda::contentsToGrid(const QPoint &pos) const
 QPoint Agenda::gridToContents(const QPoint &gpos) const
 {
     int x = int(QApplication::isRightToLeft()
-                ? (d->mColumns - gpos.x()) * d->mGridSpacingX : gpos.x() * d->mGridSpacingX);
+                ? (d->mColumns - gpos.x()) * d->mGridSpacingX
+                : gpos.x() * d->mGridSpacingX);
     int y = int(gpos.y() * d->mGridSpacingY);
     return QPoint(x, y);
 }
@@ -1711,7 +1756,7 @@ QVector<int> Agenda::minContentsY() const
 {
     QVector<int> minArray;
     minArray.fill(timeToY(QTime(23, 59)), d->mSelectedDates.count());
-    for (AgendaItem::QPtr item : qAsConst(d->mItems)) {
+    for (const AgendaItem::QPtr &item : qAsConst(d->mItems)) {
         if (item) {
             int ymin = item->cellYTop();
             int index = item->cellXLeft();
@@ -1730,7 +1775,7 @@ QVector<int> Agenda::maxContentsY() const
 {
     QVector<int> maxArray;
     maxArray.fill(timeToY(QTime(0, 0)), d->mSelectedDates.count());
-    for (AgendaItem::QPtr item : qAsConst(d->mItems)) {
+    for (const AgendaItem::QPtr &item : qAsConst(d->mItems)) {
         if (item) {
             int ymax = item->cellYBottom();
 
@@ -1746,7 +1791,7 @@ QVector<int> Agenda::maxContentsY() const
     return maxArray;
 }
 
-void Agenda::setStartTime(const QTime &startHour)
+void Agenda::setStartTime(QTime startHour)
 {
     const double startPos
         = (startHour.hour() / 24. + startHour.minute() / 1440. + startHour.second() / 86400.)
@@ -1758,9 +1803,7 @@ void Agenda::setStartTime(const QTime &startHour)
 /*
   Insert AgendaItem into agenda.
 */
-AgendaItem::QPtr Agenda::insertItem(const KCalCore::Incidence::Ptr &incidence,
-                                    const QDateTime &recurrenceId, int X, int YTop, int YBottom,
-                                    int itemPos, int itemCount, bool isSelected)
+AgendaItem::QPtr Agenda::insertItem(const KCalendarCore::Incidence::Ptr &incidence, const QDateTime &recurrenceId, int X, int YTop, int YBottom, int itemPos, int itemCount, bool isSelected)
 {
     if (d->mAllDayMode) {
         qCDebug(CALENDARVIEW_LOG) << "using this in all-day mode is illegal.";
@@ -1780,10 +1823,8 @@ AgendaItem::QPtr Agenda::insertItem(const KCalCore::Incidence::Ptr &incidence,
         YBottom = YTop;
     }
 
-    agendaItem->resize(int((X + 1) * d->mGridSpacingX)
-                       -int(X * d->mGridSpacingX),
-                       int(YTop * d->mGridSpacingY)
-                       -int((YBottom + 1) * d->mGridSpacingY));
+    agendaItem->resize(int((X + 1) * d->mGridSpacingX) - int(X * d->mGridSpacingX),
+                       int(YTop * d->mGridSpacingY) - int((YBottom + 1) * d->mGridSpacingY));
     agendaItem->setCellXY(X, YTop, YBottom);
     agendaItem->setCellXRight(X);
     agendaItem->setResourceColor(d->mCalendar->resourceColor(incidence));
@@ -1805,9 +1846,7 @@ AgendaItem::QPtr Agenda::insertItem(const KCalCore::Incidence::Ptr &incidence,
 /*
   Insert all-day AgendaItem into agenda.
 */
-AgendaItem::QPtr Agenda::insertAllDayItem(const KCalCore::Incidence::Ptr &incidence,
-                                          const QDateTime &recurrenceId, int XBegin, int XEnd,
-                                          bool isSelected)
+AgendaItem::QPtr Agenda::insertAllDayItem(const KCalendarCore::Incidence::Ptr &incidence, const QDateTime &recurrenceId, int XBegin, int XEnd, bool isSelected)
 {
     if (!d->mAllDayMode) {
         qCCritical(CALENDARVIEW_LOG) << "using this in non all-day mode is illegal.";
@@ -1825,8 +1864,7 @@ AgendaItem::QPtr Agenda::insertAllDayItem(const KCalCore::Incidence::Ptr &incide
     agendaItem->setCellXRight(XEnd);
 
     const double startIt = d->mGridSpacingX * (agendaItem->cellXLeft());
-    const double endIt = d->mGridSpacingX * (agendaItem->cellWidth()
-                                             +agendaItem->cellXLeft());
+    const double endIt = d->mGridSpacingX * (agendaItem->cellWidth() + agendaItem->cellXLeft());
 
     agendaItem->resize(int(endIt) - int(startIt), int(d->mGridSpacingY));
 
@@ -1842,9 +1880,7 @@ AgendaItem::QPtr Agenda::insertAllDayItem(const KCalCore::Incidence::Ptr &incide
     return agendaItem;
 }
 
-AgendaItem::QPtr Agenda::createAgendaItem(const KCalCore::Incidence::Ptr &incidence, int itemPos,
-                                          int itemCount, const QDateTime &recurrenceId,
-                                          bool isSelected)
+AgendaItem::QPtr Agenda::createAgendaItem(const KCalendarCore::Incidence::Ptr &incidence, int itemPos, int itemCount, const QDateTime &recurrenceId, bool isSelected)
 {
     if (!incidence) {
         qCWarning(CALENDARVIEW_LOG) << "Agenda::createAgendaItem() item is invalid.";
@@ -1863,10 +1899,9 @@ AgendaItem::QPtr Agenda::createAgendaItem(const KCalCore::Incidence::Ptr &incide
     return agendaItem;
 }
 
-void Agenda::insertMultiItem(const KCalCore::Incidence::Ptr &event, const QDateTime &recurrenceId,
-                             int XBegin, int XEnd, int YTop, int YBottom, bool isSelected)
+void Agenda::insertMultiItem(const KCalendarCore::Incidence::Ptr &event, const QDateTime &recurrenceId, int XBegin, int XEnd, int YTop, int YBottom, bool isSelected)
 {
-    KCalCore::Event::Ptr ev = CalendarSupport::event(event);
+    KCalendarCore::Event::Ptr ev = CalendarSupport::event(event);
     Q_ASSERT(ev);
     if (d->mAllDayMode) {
         qCDebug(CALENDARVIEW_LOG) << "using this in all-day mode is illegal.";
@@ -1930,7 +1965,7 @@ void Agenda::insertMultiItem(const KCalCore::Incidence::Ptr &event, const QDateT
     marcus_bains();
 }
 
-void Agenda::removeIncidence(const KCalCore::Incidence::Ptr &incidence)
+void Agenda::removeIncidence(const KCalendarCore::Incidence::Ptr &incidence)
 {
     if (!incidence) {
         qCWarning(CALENDARVIEW_LOG) << "Agenda::removeIncidence() incidence is invalid"
@@ -1942,18 +1977,18 @@ void Agenda::removeIncidence(const KCalCore::Incidence::Ptr &incidence)
         return; // It's already queued for deletion
     }
 
-    AgendaItem::List agendaItems = d->mAgendaItemsById.values(incidence->uid());
+    const AgendaItem::List agendaItems = d->mAgendaItemsById.values(incidence->uid());
     if (agendaItems.isEmpty()) {
         // We're not displaying such item
         // qCDebug(CALENDARVIEW_LOG) << "Ignoring";
         return;
     }
-    foreach (const AgendaItem::QPtr &agendaItem, agendaItems) {
+    for (const AgendaItem::QPtr &agendaItem : agendaItems) {
         if (agendaItem) {
             if (incidence->instanceIdentifier() != agendaItem->incidence()->instanceIdentifier()) {
                 continue;
             }
-            if (removeAgendaItem(agendaItem)) {
+            if (!removeAgendaItem(agendaItem)) {
                 qCWarning(CALENDARVIEW_LOG) << "Agenda::removeIncidence() Failed to remove "
                                             << incidence->uid();
             }
@@ -2061,7 +2096,7 @@ void Agenda::resizeEvent(QResizeEvent *ev)
 void Agenda::resizeAllContents()
 {
     double subCellWidth;
-    foreach (const AgendaItem::QPtr &item, d->mItems) {
+    for (const AgendaItem::QPtr &item : qAsConst(d->mItems)) {
         if (item) {
             subCellWidth = calcSubCellWidth(item);
             placeAgendaItem(item, subCellWidth);
@@ -2195,11 +2230,11 @@ void Agenda::deselectItem()
         return;
     }
 
-    const KCalCore::Incidence::Ptr selectedItem = d->mSelectedItem->incidence();
+    const KCalendarCore::Incidence::Ptr selectedItem = d->mSelectedItem->incidence();
 
-    foreach (AgendaItem::QPtr item, d->mItems) {
+    for (AgendaItem::QPtr item : qAsConst(d->mItems)) {
         if (item) {
-            const KCalCore::Incidence::Ptr itemInc = item->incidence();
+            const KCalendarCore::Incidence::Ptr itemInc = item->incidence();
             if (itemInc && selectedItem && itemInc->uid() == selectedItem->uid()) {
                 item->select(false);
             }
@@ -2216,7 +2251,7 @@ void Agenda::selectItem(const AgendaItem::QPtr &item)
     }
     deselectItem();
     if (item == nullptr) {
-        Q_EMIT incidenceSelected(KCalCore::Incidence::Ptr(), QDate());
+        Q_EMIT incidenceSelected(KCalendarCore::Incidence::Ptr(), QDate());
         return;
     }
     d->mSelectedItem = item;
@@ -2273,22 +2308,20 @@ void Agenda::calculateWorkingHours()
     d->mWorkingHoursEnable = !d->mAllDayMode;
 
     QTime tmp = d->preferences()->workingHoursStart().time();
-    d->mWorkingHoursYTop = int(4 * d->mGridSpacingY
-                               *(tmp.hour() + tmp.minute() / 60.
-                                 +tmp.second() / 3600.));
+    d->mWorkingHoursYTop
+        = int(4 * d->mGridSpacingY * (tmp.hour() + tmp.minute() / 60. + tmp.second() / 3600.));
     tmp = d->preferences()->workingHoursEnd().time();
-    d->mWorkingHoursYBottom = int(4 * d->mGridSpacingY
-                                  *(tmp.hour() + tmp.minute() / 60.
-                                    +tmp.second() / 3600.) - 1);
+    d->mWorkingHoursYBottom
+        = int(4 * d->mGridSpacingY * (tmp.hour() + tmp.minute() / 60. + tmp.second() / 3600.) - 1);
 }
 
-void Agenda::setDateList(const KCalCore::DateList &selectedDates)
+void Agenda::setDateList(const KCalendarCore::DateList &selectedDates)
 {
     d->mSelectedDates = selectedDates;
     marcus_bains();
 }
 
-KCalCore::DateList Agenda::dateList() const
+KCalendarCore::DateList Agenda::dateList() const
 {
     return d->mSelectedDates;
 }
@@ -2337,8 +2370,7 @@ AgendaItem::List Agenda::agendaItems(const QString &uid) const
     return d->mAgendaItemsById.values(uid);
 }
 
-AgendaScrollArea::AgendaScrollArea(bool isAllDay, AgendaView *agendaView, bool isInteractive,
-                                   QWidget *parent)
+AgendaScrollArea::AgendaScrollArea(bool isAllDay, AgendaView *agendaView, bool isInteractive, QWidget *parent)
     : QScrollArea(parent)
 {
     if (isAllDay) {
