@@ -75,7 +75,6 @@ enum {
 
 class Q_DECL_HIDDEN EventIndicator::Private
 {
-    EventIndicator *const q;
 
 public:
     Private(EventIndicator *parent, EventIndicator::Location loc)
@@ -118,6 +117,8 @@ public:
     Location mLocation;
     QPixmap mPixmap;
     QVector<bool> mEnabled;
+private:
+    EventIndicator *const q;
 };
 
 EventIndicator::EventIndicator(Location loc, QWidget *parent)
@@ -1515,7 +1516,6 @@ void AgendaView::updateEventDates(AgendaItem *item, bool addIncidence, Akonadi::
     }
 
     int daysLength = 0;
-    //  startDt.setDate(startDate);
 
     KCalendarCore::Incidence::Ptr incidence = item->incidence();
     Akonadi::Item aitem = d->mViewCalendar->item(incidence);
@@ -1575,33 +1575,6 @@ void AgendaView::updateEventDates(AgendaItem *item, bool addIncidence, Akonadi::
             QTimer::singleShot(0, this, &AgendaView::updateView);
             return;
         }
-    } else if (const KCalendarCore::Todo::Ptr td = CalendarSupport::todo(incidence)) {
-        startDt = td->hasStartDate() ? td->dtStart() : td->dtDue();
-        // convert to calendar timespec because we then manipulate it with time coming from
-        // the calendar
-        startDt = startDt.toLocalTime();
-        startDt.setDate(thisDate.addDays(td->dtDue().daysTo(startDt)));
-        if (!td->allDay()) {
-            startDt.setTime(startTime);
-        }
-
-        endDt = startDt;
-        endDt.setDate(thisDate);
-        if (!td->allDay()) {
-            endDt.setTime(endTime);
-        }
-
-        if (td->dtDue().toLocalTime() == endDt) {
-            // No change
-            QMetaObject::invokeMethod(this, &AgendaView::updateView, Qt::QueuedConnection);
-            return;
-        }
-    }
-
-    // A commented code block which had 150 lines to adjust recurrence was here.
-    // I deleted it in rev 1180272 to make this function readable.
-
-    if (const KCalendarCore::Event::Ptr ev = CalendarSupport::event(incidence)) {
         /* setDtEnd() must be called before setDtStart(), otherwise, when moving
          * events, CalendarLocal::incidenceUpdated() will not remove the old hash
          * and that causes the event to be shown in the old date also (bug #179157).
@@ -1612,10 +1585,24 @@ void AgendaView::updateEventDates(AgendaItem *item, bool addIncidence, Akonadi::
             endDt.toTimeSpec(incidence->dateTime(KCalendarCore::Incidence::RoleEnd).timeSpec()));
         incidence->setDtStart(startDt.toTimeSpec(incidence->dtStart().timeSpec()));
     } else if (const KCalendarCore::Todo::Ptr td = CalendarSupport::todo(incidence)) {
+        endDt = td->dtDue(true).toLocalTime().addDays(daysOffset);
+        endDt.setTime(td->allDay() ? QTime(00, 00, 00) : endTime);
+
+        if (td->dtDue(true).toLocalTime() == endDt) {
+            // No change
+            QMetaObject::invokeMethod(this, &AgendaView::updateView, Qt::QueuedConnection);
+            return;
+        }
+
+        const auto shift = td->dtDue(true).secsTo(endDt);
+        startDt = td->dtStart(true).addSecs(shift);
         if (td->hasStartDate()) {
             td->setDtStart(startDt.toTimeSpec(incidence->dtStart().timeSpec()));
         }
-        td->setDtDue(endDt.toTimeSpec(td->dtDue().timeSpec()));
+        if (td->recurs()) {
+            td->setDtRecurrence(td->dtRecurrence().addSecs(shift));
+        }
+        td->setDtDue(endDt.toTimeSpec(td->dtDue().timeSpec()), true);
     }
 
     if (!incidence->hasRecurrenceId()) {
@@ -1841,8 +1828,6 @@ bool AgendaView::displayIncidence(const KCalendarCore::Incidence::Ptr &incidence
         return false;
     }
 
-    lastVisibleDateTime.setTime(QTime(23, 59, 59, 59));
-    firstVisibleDateTime.setTime(QTime(0, 0));
     std::vector<QDateTime> dateTimeList;
 
     const QDateTime incDtStart = incidence->dtStart().toLocalTime();
@@ -1866,7 +1851,11 @@ bool AgendaView::displayIncidence(const KCalendarCore::Incidence::Ptr &incidence
                                          startDateTimeWithOffset, lastVisibleDateTime);
         while (rIt.hasNext()) {
             rIt.next();
-            const auto occurrenceDate = rIt.occurrenceStartDate().toLocalTime();
+            auto occurrenceDate = rIt.occurrenceStartDate().toLocalTime();
+            if (const auto todo = CalendarSupport::todo(rIt.incidence())) {
+                // Recurrence exceptions may have durations different from the normal recurrences.
+                occurrenceDate = occurrenceDate.addSecs(todo->dtStart().secsTo(todo->dtDue()));
+            }
             const bool makesDayBusy
                 = preferences()->colorAgendaBusyDays() && makesWholeDayBusy(rIt.incidence());
             if (makesDayBusy) {
@@ -1887,9 +1876,9 @@ bool AgendaView::displayIncidence(const KCalendarCore::Incidence::Ptr &incidence
             // If it's not overdue it will be shown at the original date (not today)
             dateToAdd = todo->dtDue().toLocalTime();
 
-            // To-dos are drawn with the bottom of the rectangle at dtDue
-            // if dtDue is at 00:00, then it should be displayed in the previous day, at 23:59
-            if (dateToAdd.time() == QTime(0, 0)) {
+            // To-dos due at a specific time are drawn with the bottom of the rectangle at dtDue.
+            // If dtDue is at 00:00, then it should be displayed in the previous day, at 23:59.
+            if (!todo->allDay() && dateToAdd.time() == QTime(0, 0)) {
                 dateToAdd = dateToAdd.addSecs(-1);
             }
 
@@ -1902,7 +1891,7 @@ bool AgendaView::displayIncidence(const KCalendarCore::Incidence::Ptr &incidence
         if (dateToAdd.isValid() && incidence->allDay()) {
             // so comparisons with < > actually work
             dateToAdd.setTime(QTime(0, 0));
-            incidenceEnd.setTime(QTime(23, 59, 59, 59));
+            incidenceEnd.setTime(QTime(23, 59, 59, 999));
         }
 
         if (dateToAdd <= lastVisibleDateTime && incidenceEnd > firstVisibleDateTime) {
@@ -2012,6 +2001,35 @@ void AgendaView::slotIncidencesDropped(const QList<QUrl> &items, const QPoint &g
 #endif
 }
 
+static void setDateTime(KCalendarCore::Incidence::Ptr incidence, QDateTime dt, bool allDay)
+{
+    incidence->setAllDay(allDay);
+
+    if (auto todo = CalendarSupport::todo(incidence)) {
+        // To-dos are displayed on their due date and time.  Make sure the todo is displayed
+        // where it was dropped.
+        QDateTime dtStart = todo->dtStart();
+        if (dtStart.isValid()) {
+            auto duration = todo->dtStart().daysTo(todo->dtDue());
+            dtStart = dt.addDays(-duration);
+            dtStart.setTime({0, 0, 0});
+        }
+        // Set dtDue before dtStart;  see comment in updateEventDates().
+        todo->setDtDue(dt, true);
+        todo->setDtStart(dtStart);
+    } else if (auto event = CalendarSupport::event(incidence)) {
+        auto duration = event->dtStart().secsTo(event->dtEnd());
+        if (duration == 0) {
+            auto defaultDuration = CalendarSupport::KCalPrefs::instance()->defaultDuration().time();
+            duration = (defaultDuration.hour() * 3600) + (defaultDuration.minute() * 60);
+        }
+        event->setDtEnd(dt.addSecs(duration));
+        event->setDtStart(dt);
+    } else {    // Can't happen, but ...
+        incidence->setDtStart(dt);
+    }
+}
+
 void AgendaView::slotIncidencesDropped(const KCalendarCore::Incidence::List &incidences, const QPoint &gpos, bool allDay)
 {
     if (gpos.x() < 0 || gpos.y() < 0) {
@@ -2019,7 +2037,8 @@ void AgendaView::slotIncidencesDropped(const KCalendarCore::Incidence::List &inc
     }
 
     const QDate day = d->mSelectedDates[gpos.x()];
-    QDateTime newTime(day, {}, Qt::LocalTime);
+    const QTime time = d->mAgenda->gyToTime(gpos.y());
+    QDateTime newTime(day, time, Qt::LocalTime);
 
     for (const KCalendarCore::Incidence::Ptr &incidence : incidences) {
         const Akonadi::Item existingItem = calendar()->item(incidence);
@@ -2030,21 +2049,19 @@ void AgendaView::slotIncidencesDropped(const KCalendarCore::Incidence::List &inc
         if (existingItem.isValid() && existsInSameCollection) {
             KCalendarCore::Incidence::Ptr newIncidence
                 = existingItem.payload<KCalendarCore::Incidence::Ptr>();
-            KCalendarCore::Incidence::Ptr oldIncidence(newIncidence->clone());
 
             if (newIncidence->dtStart() == newTime && newIncidence->allDay() == allDay) {
                 // Nothing changed
                 continue;
             }
 
-            newIncidence->setAllDay(allDay);
-            newIncidence->setDateTime(newTime, KCalendarCore::Incidence::RoleDnD);
+            KCalendarCore::Incidence::Ptr oldIncidence(newIncidence->clone());
+            setDateTime(newIncidence, newTime, allDay);
 
-            changer()->modifyIncidence(existingItem, oldIncidence, this);
+            (void) changer()->modifyIncidence(existingItem, oldIncidence, this);
         } else { // Create a new one
-            // The drop came from another application create a new incidence
-            incidence->setDateTime(newTime, KCalendarCore::Incidence::RoleDnD);
-            incidence->setAllDay(allDay);
+            // The drop came from another application.  Create a new incidence.
+            setDateTime(incidence, newTime, allDay);
             incidence->setUid(KCalendarCore::CalFormat::createUniqueId());
             Akonadi::Collection collection(collectionId());
             const bool added = -1 != changer()->createIncidence(incidence, collection, this);
@@ -2052,7 +2069,7 @@ void AgendaView::slotIncidencesDropped(const KCalendarCore::Incidence::List &inc
             if (added) {
                 // TODO: make async
                 if (existingItem.isValid()) {   // Dragged from one agenda to another, delete origin
-                    changer()->deleteIncidence(existingItem);
+                    (void) changer()->deleteIncidence(existingItem);
                 }
             }
         }
