@@ -35,20 +35,20 @@
 #include <Akonadi/Calendar/IncidenceChanger>
 
 #include <KCalUtils/IncidenceFormatter>
-#include <KCalCore/Visitor>
+#include <KCalendarCore/Visitor>
 
 #include <KConfig>
 #include <KConfigGroup>
-#include <KIconLoader>
 
 #include "calendarview_debug.h"
 #include <QBoxLayout>
 #include <QHeaderView>
+#include <QIcon>
 #include <QTreeWidget>
 #include <QLocale>
 
 using namespace EventViews;
-using namespace KCalCore;
+using namespace KCalendarCore;
 using namespace KCalUtils;
 
 enum {
@@ -59,6 +59,9 @@ enum {
     Dummy_EOF_Column // Dummy enum value for iteration purposes only. Always keep at the end.
 };
 
+static const QTime DAY_START {00, 00};
+static const QTime DAY_END   {23, 59, 59, 999};
+
 static QString cleanSummary(const QString &summary, const QDateTime &next)
 {
     QString retStr = summary;
@@ -96,17 +99,11 @@ bool ListViewItem::operator<(const QTreeWidgetItem &other) const
 
     switch (treeWidget()->sortColumn()) {
     case StartDateTime_Column:
-        return otheritem->start < start;
+        // Missing start times are sorted before any defined time.
+        return otheritem->start.isValid() && (!start.isValid() || start < otheritem->start);
     case EndDateTime_Column:
-    {
-        Incidence::Ptr thisInc = CalendarSupport::incidence(mIncidence);
-        const auto thisEnd = thisInc->dateTime(Incidence::RoleEnd).toLocalTime();
-
-        Incidence::Ptr otherInc = CalendarSupport::incidence(otheritem->mIncidence);
-        const auto otherEnd = otherInc->dateTime(Incidence::RoleEnd).toLocalTime();
-
-        return otherEnd < thisEnd;
-    }
+        // Missing end times are sorted after any defined time.
+        return end.isValid() && (!otheritem->end.isValid() || end < otheritem->end);
     default:
         return QTreeWidgetItem::operator <(other);
     }
@@ -123,8 +120,8 @@ public:
     {
     }
 
-    void addIncidences(const Akonadi::ETMCalendar::Ptr &calendar, const KCalCore::Incidence::List &incidenceList, const QDate &date);
-    void addIncidence(const Akonadi::ETMCalendar::Ptr &calendar, const KCalCore::Incidence::Ptr &, const QDate &date);
+    void addIncidences(const Akonadi::ETMCalendar::Ptr &calendar, const KCalendarCore::Incidence::List &incidenceList, const QDate &date);
+    void addIncidence(const Akonadi::ETMCalendar::Ptr &calendar, const KCalendarCore::Incidence::Ptr &, const QDate &date);
     void addIncidence(const Akonadi::ETMCalendar::Ptr &calendar, const Akonadi::Item &, const QDate &date);
     ListViewItem *getItemForIncidence(const Akonadi::Item &);
 
@@ -145,7 +142,7 @@ public:
   This class provides the initialization of a ListViewItem for calendar
   components using the Incidence::Visitor.
 */
-class ListView::Private::ListItemVisitor : public KCalCore::Visitor
+class ListView::Private::ListItemVisitor : public KCalendarCore::Visitor
 {
 public:
     ListItemVisitor(ListViewItem *item, QDate dt) : mItem(item)
@@ -153,7 +150,7 @@ public:
     {
     }
 
-    ~ListItemVisitor()
+    ~ListItemVisitor() override
     {
     }
 
@@ -184,20 +181,23 @@ bool ListView::Private::ListItemVisitor::visit(const Event::Ptr &e)
     mItem->setIcon(Summary_Column, eventPxmp);
 
     QDateTime next;
-    mItem->start = e->dtStart().toLocalTime();
-    mItem->end = e->dtEnd().toLocalTime();
     if (e->recurs()) {
-        const int duration = e->dtStart().secsTo(e->dtEnd());
-        QDateTime kdt(mStartDate, QTime(0, 0, 0));
-        kdt = kdt.addSecs(-1);
+        const qint64 duration = e->dtStart().secsTo(e->dtEnd());
+        QDateTime kdt(mStartDate, DAY_START);
+        kdt = kdt.addMSecs(-1);
         mItem->start = e->recurrence()->getNextDateTime(kdt).toLocalTime();
         mItem->end = mItem->start.addSecs(duration);
         next = e->recurrence()->getNextDateTime(mItem->start).toLocalTime();
+    } else {
+        mItem->start = e->dtStart().toLocalTime();
+        mItem->end = e->dtEnd().toLocalTime();
     }
 
     mItem->setText(Summary_Column, cleanSummary(e->summary(), next));
 
     if (e->allDay()) {
+        mItem->start.setTime(DAY_START);
+        mItem->end.setTime(DAY_END);
         mItem->setText(StartDateTime_Column,
                        QLocale().toString(mItem->start.date(), QLocale::ShortFormat));
         mItem->setText(EndDateTime_Column,
@@ -217,6 +217,25 @@ bool ListView::Private::ListItemVisitor::visit(const Todo::Ptr &t)
 {
     mItem->setIcon(Summary_Column, QIcon::fromTheme(t->iconName()));
 
+    if (t->recurs()) {
+        QDateTime kdt(mStartDate, DAY_START);
+        kdt = kdt.addMSecs(-1);
+        mItem->start = t->recurrence()->getNextDateTime(kdt).toLocalTime();
+        if (t->hasDueDate()) {
+            const qint64 duration = t->dtStart().secsTo(t->dtDue());
+            mItem->end = mItem->start.addSecs(duration);
+        } else {
+            mItem->end = QDateTime();
+        }
+    } else {
+        mItem->start = t->hasStartDate() ? t->dtStart().toLocalTime() : QDateTime();
+        mItem->end = t->hasDueDate() ? t->dtDue().toLocalTime() : QDateTime();
+    }
+    if (t->allDay()) {
+        mItem->start.setTime(DAY_START);
+        mItem->end.setTime(DAY_END);
+    }
+
     mItem->setText(Summary_Column, cleanSummary(t->summary(), QDateTime()));
 
     if (t->hasStartDate()) {
@@ -251,8 +270,11 @@ bool ListView::Private::ListItemVisitor::visit(const Todo::Ptr &t)
 
 bool ListView::Private::ListItemVisitor::visit(const Journal::Ptr &j)
 {
-    static const QPixmap jrnalPxmp = SmallIcon(j->iconName());
-    mItem->setIcon(Summary_Column, jrnalPxmp);
+    mItem->setIcon(Summary_Column, QIcon::fromTheme(j->iconName()));
+
+    mItem->start = j->dtStart();
+    mItem->end = QDateTime();
+
     if (j->summary().isEmpty()) {
         mItem->setText(Summary_Column,
                        cleanSummary(j->description().section(QLatin1Char('\n'), 0, 0),
@@ -261,12 +283,15 @@ bool ListView::Private::ListItemVisitor::visit(const Journal::Ptr &j)
         mItem->setText(Summary_Column, cleanSummary(j->summary(), QDateTime()));
     }
     if (j->allDay()) {
+        mItem->start.setTime(DAY_START);
         mItem->setText(StartDateTime_Column,
                        QLocale().toString(j->dtStart().toLocalTime().date(), QLocale::ShortFormat));
     } else {
         mItem->setText(StartDateTime_Column,
                        QLocale().toString(j->dtStart().toLocalTime(), QLocale::ShortFormat));
     }
+    mItem->setText(EndDateTime_Column, QStringLiteral("---"));
+    mItem->setText(Categories_Column, j->categoriesStr());
 
     return true;
 }
@@ -303,8 +328,6 @@ ListView::ListView(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *parent, b
                      this, &ListView::popupMenu);
     QObject::connect(d->mTreeWidget, &QTreeWidget::itemSelectionChanged,
                      this, &ListView::processSelectionChange);
-    // TODO
-    //d->mTreeWidget->restoreLayout( KOGlobals::self()->config(), "ListView Layout" );
 
     d->mSelectedDates.append(QDate::currentDate());
 
@@ -350,7 +373,7 @@ void ListView::updateView()
     for (int col = StartDateTime_Column; col < Dummy_EOF_Column; ++col) {
         d->mTreeWidget->resizeColumnToContents(col);
     }
-    d->mTreeWidget->sortItems(StartDateTime_Column, Qt::DescendingOrder);
+    d->mTreeWidget->sortItems(StartDateTime_Column, Qt::AscendingOrder);
 }
 
 void ListView::showDates(const QDate &start, const QDate &end, const QDate &preferredMonth)
@@ -385,10 +408,10 @@ void ListView::showAll()
 }
 
 void ListView::Private::addIncidences(const Akonadi::ETMCalendar::Ptr &calendar,
-                                      const KCalCore::Incidence::List &incidences,
+                                      const KCalendarCore::Incidence::List &incidences,
                                       const QDate &date)
 {
-    for (const KCalCore::Incidence::Ptr &incidence : incidences) {
+    for (const KCalendarCore::Incidence::Ptr &incidence : incidences) {
         addIncidence(calendar, incidence, date);
     }
 }
@@ -397,13 +420,13 @@ void ListView::Private::addIncidence(const Akonadi::ETMCalendar::Ptr &calendar,
                                      const Akonadi::Item &item, const QDate &date)
 {
     Q_ASSERT(calendar);
-    if (item.isValid() && item.hasPayload<KCalCore::Incidence::Ptr>()) {
-        addIncidence(calendar, item.payload<KCalCore::Incidence::Ptr>(), date);
+    if (item.isValid() && item.hasPayload<KCalendarCore::Incidence::Ptr>()) {
+        addIncidence(calendar, item.payload<KCalendarCore::Incidence::Ptr>(), date);
     }
 }
 
 void ListView::Private::addIncidence(const Akonadi::ETMCalendar::Ptr &calendar,
-                                     const KCalCore::Incidence::Ptr &incidence, const QDate &date)
+                                     const KCalendarCore::Incidence::Ptr &incidence, const QDate &date)
 {
     if (!incidence) {
         return;
