@@ -24,6 +24,7 @@
 #include "monthgraphicsitems.h"
 #include "monthitem.h"
 #include "monthview.h"
+#include "helper.h"
 #include "prefs.h"
 
 #include <CalendarSupport/Utils>
@@ -38,13 +39,6 @@ static const int AUTO_REPEAT_DELAY = 600;
 
 using namespace EventViews;
 
-//moved to helper in 5.13.0
-static bool isColorDark(const QColor &c)
-{
-    double luminance = (c.red() * 0.299) + (c.green() * 0.587) + (c.blue() * 0.114);
-    return (luminance < 128.0) ? true : false;
-}
-
 MonthScene::MonthScene(MonthView *parent)
     : QGraphicsScene(parent)
     , mMonthView(parent)
@@ -264,7 +258,7 @@ void MonthGraphicsView::drawBackground(QPainter *p, const QRectF &rect)
                 color = palette().color(QPalette::AlternateBase);
             }
         }
-        const bool usingDark = isColorDark(color);
+        const bool usingDark = EventViews::isColorDark(color);
         if (cell == mScene->selectedCell()) {
             color = (usingDark) ? color.lighter(150) : color.darker(115);
         }
