@@ -18,39 +18,34 @@
   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 #include "multiagendaview.h"
-#include "configdialoginterface.h"
-#include "prefs.h"
 
+#include "prefs.h"
 #include "agenda/agenda.h"
 #include "agenda/agendaview.h"
 #include "agenda/timelabelszone.h"
+#include "configdialoginterface.h"
+#include "calendarview_debug.h"
+
+#include <AkonadiCore/EntityTreeModel>
+#include <AkonadiWidgets/ETMViewStateSaver>
 
-#include <entitytreemodel.h>
-#include <Akonadi/Calendar/ETMCalendar>
 #include <CalendarSupport/CollectionSelection>
 #include <CalendarSupport/Utils>
 
-#include <ETMViewStateSaver>
-
-#include <KCalCore/Event>
-
 #include <KCheckableProxyModel>
 #include <KLocalizedString>
-#include <QVBoxLayout>
+#include <KRearrangeColumnsProxyModel>
 #include <KViewStateMaintainer>
-#include "calendarview_debug.h"
 
 #include <QHBoxLayout>
-#include <QItemSelectionModel>
 #include <QLabel>
+#include <QPainter>
 #include <QResizeEvent>
 #include <QScrollArea>
 #include <QScrollBar>
-#include <QSplitter>
 #include <QSortFilterProxyModel>
+#include <QSplitter>
 #include <QTimer>
-#include <QPainter>
-#include <KRearrangeColumnsProxyModel>
 
 using namespace Akonadi;
 using namespace EventViews;
@@ -164,14 +159,14 @@ MultiAgendaView::MultiAgendaView(QWidget *parent)
 {
     QHBoxLayout *topLevelLayout = new QHBoxLayout(this);
     topLevelLayout->setSpacing(0);
-    topLevelLayout->setMargin(0);
+    topLevelLayout->setContentsMargins(0, 0, 0, 0);
 
     QFontMetrics fm(font());
     int topLabelHeight = 2 * fm.height() + fm.lineSpacing();
 
     QWidget *topSideBox = new QWidget(this);
     QVBoxLayout *topSideBoxVBoxLayout = new QVBoxLayout(topSideBox);
-    topSideBoxVBoxLayout->setMargin(0);
+    topSideBoxVBoxLayout->setContentsMargins(0, 0, 0, 0);
 
     QWidget *topSideSpacer = new QWidget(topSideBox);
     topSideBoxVBoxLayout->addWidget(topSideSpacer);
@@ -186,7 +181,7 @@ MultiAgendaView::MultiAgendaView(QWidget *parent)
 
     QWidget *sideBox = new QWidget(d->mLeftSplitter);
     QVBoxLayout *sideBoxVBoxLayout = new QVBoxLayout(sideBox);
-    sideBoxVBoxLayout->setMargin(0);
+    sideBoxVBoxLayout->setContentsMargins(0, 0, 0, 0);
 
     // compensate for the frame the agenda views but not the timelabels have
     QWidget *timeLabelTopAlignmentSpacer = new QWidget(sideBox);
@@ -217,12 +212,12 @@ MultiAgendaView::MultiAgendaView(QWidget *parent)
     topLevelLayout->addWidget(d->mScrollArea, 100);
     d->mTopBox = new QWidget(d->mScrollArea->viewport());
     QHBoxLayout *mTopBoxHBoxLayout = new QHBoxLayout(d->mTopBox);
-    mTopBoxHBoxLayout->setMargin(0);
+    mTopBoxHBoxLayout->setContentsMargins(0, 0, 0, 0);
     d->mScrollArea->setWidget(d->mTopBox);
 
     topSideBox = new QWidget(this);
     topSideBoxVBoxLayout = new QVBoxLayout(topSideBox);
-    topSideBoxVBoxLayout->setMargin(0);
+    topSideBoxVBoxLayout->setContentsMargins(0, 0, 0, 0);
 
     topSideSpacer = new QWidget(topSideBox);
     topSideBoxVBoxLayout->addWidget(topSideSpacer);
@@ -250,8 +245,8 @@ void MultiAgendaView::setCalendar(const Akonadi::ETMCalendar::Ptr &calendar)
         proxy->setSourceModel(calendar->entityTreeModel());
     }
 
-    disconnect(nullptr, SIGNAL(selectionChanged(Akonadi::Collection::List,
-                                                Akonadi::Collection::List)),
+    disconnect(nullptr,
+               SIGNAL(selectionChanged(Akonadi::Collection::List,Akonadi::Collection::List)),
                this, SLOT(forceRecreateViews()));
 
     connect(collectionSelection(), &CalendarSupport::CollectionSelection::selectionChanged,
@@ -275,8 +270,9 @@ void MultiAgendaView::recreateViews()
             d->addView(d->mCollectionSelectionModels[i], d->mCustomColumnTitles[i]);
         }
     } else {
-        Q_FOREACH (const Akonadi::Collection &i, collectionSelection()->selectedCollections()) {
-            if (i.contentMimeTypes().contains(KCalCore::Event::eventMimeType())) {
+        const auto lst = collectionSelection()->selectedCollections();
+        for (const Akonadi::Collection &i : lst) {
+            if (i.contentMimeTypes().contains(KCalendarCore::Event::eventMimeType())) {
                 d->addView(i);
             }
         }
@@ -311,7 +307,7 @@ void MultiAgendaView::forceRecreateViews()
 
 void MultiAgendaView::Private::deleteViews()
 {
-    Q_FOREACH (AgendaView *const i, mAgendaViews) {
+    for (AgendaView *const i : qAsConst(mAgendaViews)) {
         KCheckableProxyModel *proxy = i->takeCustomCollectionSelectionProxyModel();
         if (proxy && !mCollectionSelectionModels.contains(proxy)) {
             delete proxy;
@@ -327,7 +323,7 @@ void MultiAgendaView::Private::deleteViews()
 
 void MultiAgendaView::Private::setupViews()
 {
-    foreach (AgendaView *agenda, mAgendaViews) {
+    for (AgendaView *agenda : qAsConst(mAgendaViews)) {
         q->connect(agenda, SIGNAL(newEventSignal()),
                    q, SIGNAL(newEventSignal()));
         q->connect(agenda, SIGNAL(newEventSignal(QDate)),
@@ -377,14 +373,14 @@ void MultiAgendaView::Private::setupViews()
     }
 
     AgendaView *lastView = mAgendaViews.last();
-    foreach (AgendaView *agenda, mAgendaViews) {
+    for (AgendaView *agenda : qAsConst(mAgendaViews)) {
         if (agenda != lastView) {
             connect(agenda->agenda()->verticalScrollBar(), &QAbstractSlider::valueChanged,
                     lastView->agenda()->verticalScrollBar(), &QAbstractSlider::setValue);
         }
     }
 
-    foreach (AgendaView *agenda, mAgendaViews) {
+    for (AgendaView *agenda : qAsConst(mAgendaViews)) {
         agenda->readSettings();
     }
 }
@@ -397,16 +393,16 @@ MultiAgendaView::~MultiAgendaView()
 Akonadi::Item::List MultiAgendaView::selectedIncidences() const
 {
     Akonadi::Item::List list;
-    foreach (AgendaView *agendaView, d->mAgendaViews) {
+    for (AgendaView *agendaView : qAsConst(d->mAgendaViews)) {
         list += agendaView->selectedIncidences();
     }
     return list;
 }
 
-KCalCore::DateList MultiAgendaView::selectedIncidenceDates() const
+KCalendarCore::DateList MultiAgendaView::selectedIncidenceDates() const
 {
-    KCalCore::DateList list;
-    foreach (AgendaView *agendaView, d->mAgendaViews) {
+    KCalendarCore::DateList list;
+    for (AgendaView *agendaView : qAsConst(d->mAgendaViews)) {
         list += agendaView->selectedIncidenceDates();
     }
     return list;
@@ -414,7 +410,7 @@ KCalCore::DateList MultiAgendaView::selectedIncidenceDates() const
 
 int MultiAgendaView::currentDateCount() const
 {
-    foreach (AgendaView *agendaView, d->mAgendaViews) {
+    for (AgendaView *agendaView : qAsConst(d->mAgendaViews)) {
         return agendaView->currentDateCount();
     }
     return 0;
@@ -427,14 +423,14 @@ void MultiAgendaView::showDates(const QDate &start, const QDate &end, const QDat
     d->mEndDate = end;
     slotResizeScrollView();
     d->mTimeLabelsZone->updateAll();
-    foreach (AgendaView *agendaView, d->mAgendaViews) {
+    for (AgendaView *agendaView : qAsConst(d->mAgendaViews)) {
         agendaView->showDates(start, end);
     }
 }
 
 void MultiAgendaView::showIncidences(const Akonadi::Item::List &incidenceList, const QDate &date)
 {
-    foreach (AgendaView *agendaView, d->mAgendaViews) {
+    for (AgendaView *agendaView : qAsConst(d->mAgendaViews)) {
         agendaView->showIncidences(incidenceList, date);
     }
 }
@@ -442,7 +438,7 @@ void MultiAgendaView::showIncidences(const Akonadi::Item::List &incidenceList, c
 void MultiAgendaView::updateView()
 {
     recreateViews();
-    foreach (AgendaView *agendaView, d->mAgendaViews) {
+    for (AgendaView *agendaView : qAsConst(d->mAgendaViews)) {
         agendaView->updateView();
     }
 }
@@ -455,7 +451,7 @@ int MultiAgendaView::maxDatesHint() const
 
 void MultiAgendaView::slotSelectionChanged()
 {
-    foreach (AgendaView *agenda, d->mAgendaViews) {
+    for (AgendaView *agenda : qAsConst(d->mAgendaViews)) {
         if (agenda != sender()) {
             agenda->clearSelection();
         }
@@ -464,7 +460,7 @@ void MultiAgendaView::slotSelectionChanged()
 
 bool MultiAgendaView::eventDurationHint(QDateTime &startDt, QDateTime &endDt, bool &allDay) const
 {
-    foreach (AgendaView *agenda, d->mAgendaViews) {
+    for (AgendaView *agenda : qAsConst(d->mAgendaViews)) {
         bool valid = agenda->eventDurationHint(startDt, endDt, allDay);
         if (valid) {
             return true;
@@ -475,7 +471,7 @@ bool MultiAgendaView::eventDurationHint(QDateTime &startDt, QDateTime &endDt, bo
 
 void MultiAgendaView::slotClearTimeSpanSelection()
 {
-    foreach (AgendaView *agenda, d->mAgendaViews) {
+    for (AgendaView *agenda : qAsConst(d->mAgendaViews)) {
         if (agenda != sender()) {
             agenda->clearTimeSpanSelection();
         } else {
@@ -489,7 +485,7 @@ AgendaView *MultiAgendaView::Private::createView(const QString &title)
     QWidget *box = new QWidget(mTopBox);
     mTopBox->layout()->addWidget(box);
     QVBoxLayout *layout = new QVBoxLayout(box);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(new ElidedLabel(title));
     AgendaView *av = new AgendaView(q->preferences(),
                                     q->startDateTime().date(),
@@ -546,8 +542,7 @@ void MultiAgendaView::resizeEvent(QResizeEvent *ev)
 
 void MultiAgendaView::Private::resizeScrollView(const QSize &size)
 {
-    const int widgetWidth = size.width() - mTimeLabelsZone->width()
-                            -mScrollBar->width();
+    const int widgetWidth = size.width() - mTimeLabelsZone->width() - mScrollBar->width();
 
     int height = size.height();
     if (mScrollArea->horizontalScrollBar()->isVisible()) {
@@ -566,14 +561,14 @@ void MultiAgendaView::Private::resizeScrollView(const QSize &size)
 void MultiAgendaView::setIncidenceChanger(Akonadi::IncidenceChanger *changer)
 {
     EventView::setIncidenceChanger(changer);
-    foreach (AgendaView *agenda, d->mAgendaViews) {
+    for (AgendaView *agenda : qAsConst(d->mAgendaViews)) {
         agenda->setIncidenceChanger(changer);
     }
 }
 
 void MultiAgendaView::setPreferences(const PrefsPtr &prefs)
 {
-    foreach (AgendaView *agenda, d->mAgendaViews) {
+    for (AgendaView *agenda : qAsConst(d->mAgendaViews)) {
         agenda->setPreferences(prefs);
     }
     EventView::setPreferences(prefs);
@@ -584,7 +579,7 @@ void MultiAgendaView::updateConfig()
     EventView::updateConfig();
     d->mTimeLabelsZone->setPreferences(preferences());
     d->mTimeLabelsZone->updateAll();
-    foreach (AgendaView *agenda, d->mAgendaViews) {
+    for (AgendaView *agenda : qAsConst(d->mAgendaViews)) {
         agenda->updateConfig();
     }
 }
@@ -599,7 +594,7 @@ void MultiAgendaView::resizeSplitters()
     if (!lastMovedSplitter) {
         lastMovedSplitter = d->mLeftSplitter;
     }
-    foreach (AgendaView *agenda, d->mAgendaViews) {
+    for (AgendaView *agenda : qAsConst(d->mAgendaViews)) {
         if (agenda->splitter() == lastMovedSplitter) {
             continue;
         }
@@ -626,7 +621,7 @@ void MultiAgendaView::zoomView(const int delta, const QPoint &pos, const Qt::Ori
         }
     }
 
-    foreach (AgendaView *agenda, d->mAgendaViews) {
+    for (AgendaView *agenda : qAsConst(d->mAgendaViews)) {
         agenda->zoomView(delta, pos, ori);
     }
 
@@ -651,7 +646,7 @@ void MultiAgendaView::showEvent(QShowEvent *event)
 void MultiAgendaView::setChanges(Changes changes)
 {
     EventView::setChanges(changes);
-    foreach (AgendaView *agenda, d->mAgendaViews) {
+    for (AgendaView *agenda : qAsConst(d->mAgendaViews)) {
         agenda->setChanges(changes);
     }
 }
@@ -727,8 +722,8 @@ void MultiAgendaView::doRestoreConfig(const KConfigGroup &configGroup)
             KCheckableProxyModel *checkableProxy = new KCheckableProxyModel(this);
             checkableProxy->setSourceModel(columnFilterProxy);
             checkableProxy->setSelectionModel(qsm);
-            const QString groupName = configGroup.name() + QLatin1String("_subView_")
-                                      + QString::number(i);
+            const QString groupName
+                = configGroup.name() + QLatin1String("_subView_") + QString::number(i);
             const KConfigGroup group = configGroup.config()->group(groupName);
 
             if (!d->mSelectionSavers.contains(groupName)) {
@@ -753,7 +748,7 @@ void MultiAgendaView::doSaveConfig(KConfigGroup &configGroup)
     configGroup.writeEntry("CustomNumberOfColumns", d->mCustomNumberOfColumns);
     configGroup.writeEntry("ColumnTitles", d->mCustomColumnTitles);
     int idx = 0;
-    foreach (KCheckableProxyModel *checkableProxyModel, d->mCollectionSelectionModels) {
+    for (KCheckableProxyModel *checkableProxyModel : qAsConst(d->mCollectionSelectionModels)) {
         const QString groupName = configGroup.name() + QLatin1String("_subView_") + QString::number(
             idx);
         KConfigGroup group = configGroup.config()->group(groupName);
@@ -823,5 +818,5 @@ void MultiAgendaView::Private::ElidedLabel::paintEvent(QPaintEvent *event)
 QSize MultiAgendaView::Private::ElidedLabel::minimumSizeHint() const
 {
     const QFontMetrics &fm = fontMetrics();
-    return QSize(fm.width(QStringLiteral("...")), fm.height());
+    return QSize(fm.boundingRect(QStringLiteral("...")).width(), fm.height());
 }
