@@ -32,7 +32,7 @@
 #include <AkonadiCore/CollectionColorAttribute>
 
 #include <QFontDatabase>
-
+#include <QRandomGenerator>
 using namespace EventViews;
 
 QSet<EventViews::EventView::ItemIcon> iconArrayToSet(const QByteArray &array)
@@ -64,6 +64,7 @@ QByteArray iconSetToArray(const QSet<EventViews::EventView::ItemIcon> &set)
 QByteArray agendaViewIconDefaults()
 {
     QByteArray iconDefaults;
+    iconDefaults.resize(7);
 
     iconDefaults[EventViews::EventView::CalendarCustomIcon] = 1;
     iconDefaults[EventViews::EventView::TaskIcon] = 1;
@@ -79,6 +80,7 @@ QByteArray agendaViewIconDefaults()
 QByteArray monthViewIconDefaults()
 {
     QByteArray iconDefaults;
+    iconDefaults.resize(7);
 
     iconDefaults[EventViews::EventView::CalendarCustomIcon] = 1;
     iconDefaults[EventViews::EventView::TaskIcon] = 1;
@@ -548,6 +550,16 @@ void Prefs::writeConfig()
     }
 }
 
+void Prefs::setUseSystemColor(bool useSystemColor)
+{
+    d->setBool(d->mBaseConfig.useSystemColorItem(), useSystemColor);
+}
+
+bool Prefs::useSystemColor() const
+{
+    return d->getBool(d->mBaseConfig.useSystemColorItem());
+}
+
 void Prefs::setMarcusBainsShowSeconds(bool showSeconds)
 {
     d->setBool(d->mBaseConfig.marcusBainsShowSecondsItem(), showSeconds);
@@ -973,7 +985,7 @@ QColor Prefs::resourceColor(const QString &cal)
         if (seed > 0 && seed - 1 < colors.size()) {
             color.setNamedColor(colors[seed - 1]);
         } else {
-            color.setRgb(qrand() % 256, qrand() % 256, qrand() % 256);
+            color.setRgb(QRandomGenerator::global()->bounded(256), QRandomGenerator::global()->bounded(256), QRandomGenerator::global()->bounded(256));
         }
         d->setInt(d->mBaseConfig.defaultResourceColorSeedItem(), (seed + 1));
         d->mBaseConfig.setResourceColor(cal, color);
