@@ -45,7 +45,7 @@
 #include <CalendarSupport/KCalPrefs>
 #include <CalendarSupport/Utils>
 
-#include <Libkdepim/KDatePickerPopup>
+#include <CalendarSupport/KDatePickerPopup>
 
 #include <KCalendarCore/CalFormat>
 
@@ -399,25 +399,25 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
 
     mItemPopupMenu->addSeparator();
 
-    mCopyPopupMenu = new KPIM::KDatePickerPopup(KPIM::KDatePickerPopup::NoDate
-                                                |KPIM::KDatePickerPopup::DatePicker
-                                                |KPIM::KDatePickerPopup::Words,
+    mCopyPopupMenu = new CalendarSupport::KDatePickerPopup(CalendarSupport::KDatePickerPopup::NoDate
+                                                |CalendarSupport::KDatePickerPopup::DatePicker
+                                                |CalendarSupport::KDatePickerPopup::Words,
                                                 QDate::currentDate(), this);
     mCopyPopupMenu->setTitle(i18nc("@title:menu", "&Copy To"));
 
-    connect(mCopyPopupMenu, &KPIM::KDatePickerPopup::dateChanged, this, &TodoView::copyTodoToDate);
+    connect(mCopyPopupMenu, &CalendarSupport::KDatePickerPopup::dateChanged, this, &TodoView::copyTodoToDate);
 
-    connect(mCopyPopupMenu, &KPIM::KDatePickerPopup::dateChanged, mItemPopupMenu, &QMenu::hide);
+    connect(mCopyPopupMenu, &CalendarSupport::KDatePickerPopup::dateChanged, mItemPopupMenu, &QMenu::hide);
 
-    mMovePopupMenu = new KPIM:: KDatePickerPopup(KPIM::KDatePickerPopup::NoDate
-                                                 |KPIM::KDatePickerPopup::DatePicker
-                                                 |KPIM::KDatePickerPopup::Words,
+    mMovePopupMenu = new CalendarSupport:: KDatePickerPopup(CalendarSupport::KDatePickerPopup::NoDate
+                                                 |CalendarSupport::KDatePickerPopup::DatePicker
+                                                 |CalendarSupport::KDatePickerPopup::Words,
                                                  QDate::currentDate(), this);
     mMovePopupMenu->setTitle(i18nc("@title:menu", "&Move To"));
 
-    connect(mMovePopupMenu, &KPIM::KDatePickerPopup::dateChanged, this, &TodoView::setNewDate);
+    connect(mMovePopupMenu, &CalendarSupport::KDatePickerPopup::dateChanged, this, &TodoView::setNewDate);
 
-    connect(mMovePopupMenu, &KPIM::KDatePickerPopup::dateChanged, mItemPopupMenu, &QMenu::hide);
+    connect(mMovePopupMenu, &CalendarSupport::KDatePickerPopup::dateChanged, mItemPopupMenu, &QMenu::hide);
 
     mItemPopupMenu->insertMenu(nullptr, mCopyPopupMenu);
     mItemPopupMenu->insertMenu(nullptr, mMovePopupMenu);
@@ -682,7 +682,7 @@ void TodoView::addTodo(const QString &summary, const Akonadi::Item &parentItem,
         collection = calendar()->collection(parentItem.storageCollectionId());
     }
 
-    changer()->createIncidence(todo, Akonadi::Collection(), this);
+    changer()->createIncidence(todo, collection, this);
 }
 
 void TodoView::addQuickTodo(Qt::KeyboardModifiers modifiers)
@@ -962,8 +962,11 @@ void TodoView::setNewDate(const QDate &date)
 
     if (calendar()->hasRight(todoItem, Akonadi::Collection::CanChangeItem)) {
         KCalendarCore::Todo::Ptr oldTodo(todo->clone());
-
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
         QDateTime dt(date);
+#else
+        QDateTime dt(date.startOfDay());
+#endif
 
         if (!todo->allDay()) {
             dt.setTime(todo->dtDue().time());
